@@ -39,5 +39,19 @@ class EnergyParameters(seamm.Parameters):
         parameters given in the class"""
 
         super().__init__(
-            defaults={**EnergyParameters.parameters, **defaults}, data=data
+            defaults={
+                **EnergyParameters.parameters,
+                **seamm.standard_parameters.structure_handling_parameters,
+                **defaults,
+            },
+            data=data,
         )
+
+        # Do any local editing of defaults
+        tmp = self["system name"]
+        tmp._data["enumeration"] = ["simulated with {model}", *tmp.enumeration[1:]]
+        tmp.default = "keep current name"
+
+        tmp = self["configuration name"]
+        tmp._data["enumeration"] = ["simulated with {model}", *tmp.enumeration]
+        tmp.default = "simulated with {model}"
