@@ -16,10 +16,26 @@ metadata["results"] = {
         "type": "float",
         "units": "kcal/mol",
     },
+    "DfE0": {
+        "description": "the energy of formation",
+        "dimensionality": "scalar",
+        "property": "DfE0#LAMMPS#{model}",
+        "type": "float",
+        "units": "kJ/mol",
+        "format": ".2f",
+    },
+    "E atomization": {
+        "description": "the energy of formation from atoms",
+        "dimensionality": "scalar",
+        "property": "E atomization#LAMMPS#{model}",
+        "type": "float",
+        "units": "kJ/mol",
+        "format": ".2f",
+    },
     "gradients": {
-        "calculation": ["energy"],
         "description": "The gradients",
         "dimensionality": "[3, n_atoms]",
+        "property": "gradients#LAMMPS#{model}",
         "type": "float",
         "units": "kcal/mol/Å",
     },
@@ -30,7 +46,7 @@ metadata["results"] = {
     },
     "DfH0_reax": {
         "calculation": ["energy", "minimization"],
-        "description": "the Reax appriximation to the enthalpy of formation",
+        "description": "the Reax approximation to the enthalpy of formation",
         "dimensionality": "scalar",
         "property": "DfH0_reax#LAMMPS#{model}",
         "type": "float",
@@ -133,6 +149,49 @@ metadata["results"] = {
         "type": "float",
         "units": "",
     },
+    "stress": {
+        "description": "Stress Voigt vector",
+        "dimensionality": "[6]",
+        "property": "stress#LAMMPS#{model}",
+        "type": "float",
+        "units": "atm",
+    },
+    "stress,stderr": {
+        "calculation": [
+            "nve",
+            "nvt",
+            "npt",
+        ],
+        "description": "stderr of stress",
+        "dimensionality": "[6]",
+        "property": "stress, stderr#LAMMPS#{model}",
+        "type": "float",
+        "units": "atm",
+    },
+    "stress,tau": {
+        "calculation": [
+            "nve",
+            "nvt",
+            "npt",
+        ],
+        "description": "autocorrelation time of stress",
+        "dimensionality": "[6]",
+        "property": "stress, tau#LAMMPS#{model}",
+        "type": "float",
+        "units": "fs",
+    },
+    "stress,inefficiency": {
+        "calculation": [
+            "nve",
+            "nvt",
+            "npt",
+        ],
+        "description": "statistical inefficiency of stress sampling",
+        "dimensionality": "[6]",
+        "property": "stress, inefficiency#LAMMPS#{model}",
+        "type": "float",
+        "units": "",
+    },
     "Sxx": {
         "description": "Sxx",
         "dimensionality": "scalar",
