@@ -330,6 +330,30 @@ class NVE_Parameters(lammps_step.EnergyParameters):
             "description": "Include velocities:",
             "help_text": "Whether to include the velocities in the trajectory",
         },
+        "trajectory save": {
+            "default": "no",
+            "kind": "boolean",
+            "enumeration": ("yes", "no"),
+            "format_string": "",
+            "description": "Save the trajectory in a system:",
+            "help_text": "Whether to save the trajectory to a system.",
+        },
+        "trajectory system name": {
+            "default": "trajectory",
+            "kind": "string",
+            "enumeration": ("current",),
+            "format_string": "",
+            "description": "System name:",
+            "help_text": "The name of the system for the trajectory",
+        },
+        "make current": {
+            "default": "no",
+            "kind": "boolean",
+            "enumeration": ("yes", "no"),
+            "format_string": "",
+            "description": "Make it the current system:",
+            "help_text": "Whether to make the system the current system.",
+        },
         "trajectory export": {
             "default": "no",
             "kind": "boolean",
