@@ -64,18 +64,18 @@ class Velocities(seamm.Node):
 
         text = "Set the velocities to give a temperature {T} " "by {method}."
 
-        if P["remove_momentum"][0] == "$":
+        if self.is_expr(P["remove_momentum"]):
             text += (
                 " Whether to remove translational or rotational "
                 "momentum will be determined at runtime by "
                 "'{remove_momentum}'"
             )
         else:
-            text += " LAMMPS will {remove_momentum}."
+            text += " LAMMPS will {remove_momentum}"
 
         if P["method"] != "scaling current velocities":
             if P["seed"] == "random":
-                text += " The random number generator will be initialized " "randomly."
+                text += " The random number generator will be initialized randomly."
             else:
                 text += (
                     " The random number generator will be initialized "
@@ -94,13 +94,13 @@ class Velocities(seamm.Node):
             system_db = self.get_variable("_system_db")
             configuration = system_db.system.configuration
             if configuration.periodicity == 3:
-                P[
-                    "remove_momentum"
-                ] = "remove translational but not rotational momentum"
+                P["remove_momentum"] = (
+                    "remove translational but not rotational momentum"
+                )
             else:
-                P[
-                    "remove_momentum"
-                ] = "remove both translational and rotational momentum"
+                P["remove_momentum"] = (
+                    "remove both translational and rotational momentum"
+                )
         if P["seed"] == "random":
             P["seed"] = int(random.random() * 2**31)
 
@@ -110,31 +110,27 @@ class Velocities(seamm.Node):
             if isinstance(PP[key], units_class):
                 PP[key] = "{:~P}".format(PP[key])
 
-        self.description = [str(__(self.description_text(PP), **PP, indent=3 * " "))]
+        self.description = [str(__(self.description_text(PP), **PP, indent=4 * " "))]
 
         # Get the input lines
         lines = []
         lines.append("")
-        lines.append("#     velocities")
+        lines.append(f"# {self.header}")
         lines.append("")
 
-        if P["remove_momentum"] == (
-            "remove translational but not " "rotational momentum"
-        ):
+        if P["remove_momentum"] == "remove translational but not rotational momentum":
             remove_translations = "yes"
             remove_rotations = "no"
-        elif P["remove_momentum"] == (
-            "remove rotational but not " "translational momentum"
-        ):
+        elif P["remove_momentum"] == "remove rotational but not translational momentum":
             remove_translations = "no"
             remove_rotations = "yes"
         elif P["remove_momentum"] == (
-            "remove both translational and " "rotational momentum"
+            "remove both translational and rotational momentum"
         ):
             remove_translations = "yes"
             remove_rotations = "yes"
         elif P["remove_momentum"] == (
-            "remove neither translational nor " "rotational momentum"
+            "remove neither translational nor rotational momentum"
         ):
             remove_translations = "no"
             remove_rotations = "no"
@@ -162,4 +158,8 @@ class Velocities(seamm.Node):
                 "Velocity method '{}' not supported yet".format(P["method"])
             )
 
-        return lines
+        return {
+            "script": lines,
+            "postscript": None,
+            "use python": False,
+        }
